Verhindern Sie Brustkrebs - California Protonen
Description: Das Verständnis der zugrunde liegenden Ursachen und Risikofaktoren von Brustkrebs ist für die Prävention unerlässlich. Erfahren Sie, ob Sie gefährdet sind und welche Maßnahmen Sie zur Vorbeugung von Brustkrebs ergreifen können.

Brust verhindern
Krebs

Inhalt

Diagnose

Behandlungen

Ursachen & Risiken

Stufen & Noten

# Kennen Sie die Ursachen.
Verstehe deine Risiken.

Sobald Sie 20 Jahre alt sind, ist es wichtig, stets auf dem Laufenden zu bleiben und regelmäßige Brustuntersuchungen durchzuführen. Brustkrebs ist die weltweit häufigste Krebserkrankung bei Frauen, und etwa jede achte Frau in den USA wird irgendwann in ihrem Leben mit dieser Diagnose diagnostiziert. Dieser Prozentsatz erhöht sich auf 1% für diejenigen, die eine haben BRCA1 Mutation oder BRCA2 Mutation. Brustkrebs kann jedoch sehr heilbar sein, insbesondere wenn er früh erkannt wird.

## Hauptursachen für Brustkrebs

Krebs wird hauptsächlich durch Mutationen oder Veränderungen des genetischen Materials in Ihren Zellen verursacht. Einige Mutationen, mit denen Sie geboren wurden, während andere später im Leben aufgrund von Fehlern im Genreplikationsprozess erworben werden. In den meisten Fällen entsteht Krebs, wenn Zellen ihre normalen Funktionen einstellen und ein schnelles Wachstum ermöglichen, das unkontrollierte Zellwachstum nicht stoppen oder Fehler bei der Reparatur von DNA-Fehlern machen. Denken Sie daran, dass nicht alle erworbenen oder vererbten genetischen Mutationen zu Krebs werden.

## Häufige Risikofaktoren für Brustkrebs

Während Ärzte einige Korrelationen zwischen bestimmten Gesundheitszuständen und diagnostizierten Fällen festgestellt haben, tritt die Mehrzahl der Krebserkrankungen bei Menschen ohne bekannte Risikofaktoren auf. Ihr bester Ansatz ist es, zu verwalten, was Sie kontrollieren können, zu ändern, was Sie können, und sich über Veränderungen in Ihrer Gesundheit im Klaren zu sein, die eine Ursache für Brustkrebs sein könnten.

- Alter: Krebs kann sich in jedem Alter entwickeln, aber 2 von 3 invasiven Brustkrebserkrankungen treten bei Frauen ab 55 Jahren auf.
- Rasse / ethnische Zugehörigkeit: Das aschkenasische jüdische (osteuropäische) Erbe kann Sie einem höheren Risiko aussetzen. Kaukasische Frauen entwickeln etwas häufiger Brustkrebs als Frauen afroamerikanischer, hispanischer und asiatischer Abstammung. Afroamerikanische Frauen entwickeln jedoch eher in jüngerem Alter einen aggressiveren Brustkrebs.
- Vererbte genetische Mutationen: BRCA1, BRCA2 und CHEC2 Anomalien können auf 5-10% aller Fälle zurückgeführt werden.
- Familiengeschichte: Ihr genetisches Brustkrebsrisiko verdoppelt sich, wenn bei einer Verwandten ersten Grades - Schwester, Mutter oder Tochter - Brustkrebs diagnostiziert wurde. Wenn bei Ihnen zwei Verwandte ersten Grades diagnostiziert wurden, ist Ihr Risiko fünfmal höher als der Durchschnitt. Blutsverwandte, die vor dem 5. Lebensjahr oder mit dreifach nativem Brustkrebs diagnostiziert wurden, können ebenfalls Ihr Risiko erhöhen.
- Geburts- und Menstruationszyklen: Wenn Sie vor dem 30. Lebensjahr noch keine Vollzeitschwangerschaft oder Ihr erstes Kind hatten, besteht möglicherweise ein höheres Brustkrebsrisiko. Wenn Sie Ihre Periode vor dem 12. Lebensjahr beginnen und die Wechseljahre nach dem 55. Lebensjahr durchlaufen, kann sich auch Ihr Risiko erhöhen.
- Lebensstil und Umweltbelange: Rauchen, Trinken, Bewegungsmangel, ein BMI über 25, chronische Entzündungen, niedrige Vitamin D-Spiegel, übermäßige Sonneneinstrahlung oder krebserregende Chemikalien sowie unsicherer Sex können zur Entwicklung von Krebszellen beitragen.

## Tipps zur Brustkrebsvorsorge

Es gibt keine bewährte Strategie zur Vorbeugung, aber die Bildung eines gesunden Lebensstils und die Ergreifung der richtigen Gesundheitsmaßnahmen können dazu beitragen, Ihr Risiko zu verringern und Ihre Immunität zu verbessern. Jüngste Studien legen nahe, dass die Ernährung zumindest teilweise für 30 bis 40% aller Krebserkrankungen verantwortlich ist.

### 1. Rauchen Sie nicht

Rauch enthält krebserregende Verbindungen, die Krebs verursachen können. Es macht Sie auch anfälliger für behandlungsbedingte Nebenwirkungen. Wenn eine Bestrahlung erforderlich ist, besteht möglicherweise ein höheres Risiko für die Entwicklung von Lungenkrebs und / oder Pneumonitis.

### 2. Treiben Sie regelmäßig Sport

Sport hilft Ihnen bei der Kontrolle des Blutzuckers und begrenzt den Insulinspiegel eines Hormons, der das Wachstum von Brustzellen beeinflussen und krebserregende genetische Mutationen entwickeln kann. Streben Sie mindestens 150 Minuten pro Woche mäßige aerobe Aktivität oder 75 Minuten kräftige aerobe Aktivität an.

### 3. Halten Sie ein gesundes Gewicht (unter 25 BMI)

Fettzellen bilden Östrogen, das die Entwicklung und das Wachstum bestimmter Arten von Brustkrebs stimulieren kann. Zusätzliche Fettzellen können auch Entzündungen im Körper auslösen, die mit einer höheren Wahrscheinlichkeit eines erneuten Auftretens verbunden sind.

### 4. Befolgen Sie eine Diät zur Vorbeugung von Brustkrebs, indem Sie Folgendes wählen:

- Halten Sie eine Diät ein, die reich an Obst und Gemüse ist
- Pflücken Sie Vollkornprodukte, mageres Eiweiß sowie fettfreie Milch und Milchprodukte
- Entfernen Sie die Haut und das Fett von Fleisch, Geflügel und Fisch
- Begrenzen Sie Zucker, raffinierte Kohlenhydrate und Alkohol
- Essen Sie kleinere Portionen

### 5. Vermeiden Sie schädliche Exposition gegenüber Chemikalien, Toxinen, Sonne und anderer Strahlung

Weitere Studien beginnen mit der Erforschung der Umweltursachen von Brustkrebs und der Auswirkungen bestimmter Chemikalien in Kunststoffen, Kosmetika, Lebensmitteln, Wasser und anderen Konsumgütern. Der Einsatz von Pestiziden, Antibiotika und Hormonen in der Lebensmittelproduktion kann ebenfalls eine Rolle spielen.

### 6. Planen Sie jährliche Brustuntersuchungen

Früherkennung ist immer noch der beste Weg, um das Wachstum oder die Ausbreitung von Krebs zu verhindern. Mit einer 5-Jahres-Überlebensrate von etwa 100% für Brustkrebs im Stadium 0 und 1 ist es wichtig, ihn frühzeitig zu erkennen.

### 7. Suchen Sie einen Arzt auf, wenn bei Ihnen Symptome von Brustkrebs auftreten, wie z.

- Ermüden
- Klumpen oder Verdickungsbereich unter der Haut
- Unbeabsichtigte Gewichtsabnahme oder Gewichtszunahme
- Hautveränderungen wie Gelbfärbung, Verdunkelung oder Rötung der Haut
- Unerklärliche Blutungen, Blutergüsse oder Wunden, die nicht heilen
- Veränderungen der Darm- oder Blasengewohnheiten
- Anhaltender Husten, Atembeschwerden, Verdauungsstörungen oder Beschwerden nach dem Essen
- Heiserkeit oder Schluckbeschwerden
- Anhaltendes, unerklärliches Fieber, Nachtschweiß oder Muskel- und / oder Gelenkschmerzen

## Optionen zur vorbeugenden Behandlung von Brustkrebs

Eine familiäre Vorgeschichte von Brustkrebs und / oder eine bekannte genetische Mutation kann bei vielen Frauen Stress und Angst verursachen. Anstatt abzuwarten, entscheiden sich einige Frauen für einen proaktiveren und aggressiveren Ansatz, um ihre Chancen zu verringern. Am häufigsten ist die Entfernung ihrer Brust (en) und / oder Eierstöcke und die Unterdrückung des mit dem Wachstum von Krebszellen verbundenen Östrogenhormons. Es gibt zwar keine Garantie, aber es ist gut, sich mit den Arten der vorbeugenden Behandlungen vertraut zu machen, die Ihnen zur Verfügung stehen.

### Prophylaktische Mastektomie

Nach Angaben des National Cancer Institute tragen Frauen, die eine BRCA1 or BRCA2 Genmutation und die Entscheidung für eine vorbeugende Mastektomie können das Krebsrisiko möglicherweise um 95% senken. Dieser Prozentsatz sinkt bei Frauen mit einer starken familiären Vorgeschichte von Brustkrebs leicht auf 90%. Während dieser Operation werden eine oder beide Brüste entfernt, um das Risiko einer Krebsentstehung in Ihrer Brust zu verringern. Die Menge des entfernten Gewebes hängt von der Art der durchgeführten Mastektomie (z. B. insgesamt, hautschonend und nippelschonend) ab. Eine Brustrekonstruktion kann auch während oder nach der Operation möglich sein.

Mehr erfahren

### Prophylaktische Entfernung der Eierstöcke

Diese Art der Operation bietet Frauen die Möglichkeit, ihr Risiko zu senken, ohne größere sichtbare Veränderungen an ihrem Körper zu verursachen. Die Entfernung Ihrer Eierstöcke senkt die Menge an Östrogen im Körper, wodurch Brustkrebs verhindert wird, für dessen Wachstum Östrogen erforderlich ist. Das National Cancer Institute hat festgestellt, dass diese Operation die Anzahl neuer Fälle bei Frauen mit hohem Risiko um etwa 50% reduziert. Es ist wichtig zu beachten, dass diese Art der Operation nur Frauen vor der Menopause zugute kommt und die Möglichkeit, Kinder zu bekommen, ausschließt.

Mehr erfahren

### Vorbeugende Hormontherapie

Diese Art der Behandlung wird häufig für diejenigen empfohlen, bei denen keine Diagnose gestellt wurde, bei denen jedoch ein Risiko für ER- und PR-positive Brustkrebserkrankungen besteht. Bestimmte Hormone im Blut können dazu führen, dass sich diese Krebsarten im Brustgewebe bilden. Durch die Einnahme dieser hormonblockierenden Medikamente können Sie die Östrogenproduktion im Blut senken und die Stimulation der Brustzellen stoppen. Die Hormontherapie wirkt sich nicht auf Tumoren aus, die ER- und PR-negativ sind, da sie nicht durch Hormone beeinflusst werden.

Mehr erfahren

## Erfahren Sie mehr über Brustkrebs

Untersuchungen & Diagnose für Brustkrebs

Stadien und Grade von Brustkrebs

Behandlungsmöglichkeiten für Brustkrebs

English
Afrikaans Albanian Amharic Arabic Armenian Azerbaijani Basque Belarusian Bengali Bosnian Bulgarian Catalan Cebuano Chichewa Chinese (Simplified) Chinese (Traditional) Corsican Croatian Czech Danish Dutch English Esperanto Estonian Filipino Finnish French Frisian Galician Georgian German Greek Gujarati Haitian Creole Hausa Hawaiian Hebrew Hindi Hmong Hungarian Icelandic Igbo Indonesian Irish Italian Japanese Javanese Kannada Kazakh Khmer Korean Kurdish (Kurmanji) Kyrgyz Lao Latin Latvian Lithuanian Luxembourgish Macedonian Malagasy Malay Malayalam Maltese Maori Marathi Mongolian Myanmar (Burmese) Nepali Norwegian Pashto Persian Polish Portuguese Punjabi Romanian Russian Samoan Scottish Gaelic Serbian Sesotho Shona Sindhi Sinhala Slovak Slovenian Somali Spanish Sudanese Swahili Swedish Tajik Tamil Telugu Thai Turkish Ukrainian Urdu Uzbek Vietnamese Welsh Xhosa Yiddish Yoruba Zulu

## Kontaktieren Sie uns

Vorname *
Nachname*
E-Mail-Adresse*
Telefonnummer*
Wie haben Sie von uns erfahren? *
Nachricht

## Registrieren

- Vorname *
- Nachname*
- Titel *
- Wenn anders, bitte spezifizieren
- Zugehörigkeit*
- Adresse Anschrift Zeile 2 Stadt Bundesland
  Postleitzahl (USA)
- E–Mail*
- Spezialprodukte
- Wenn anders, bitte spezifizieren
- Wie haben Sie von dieser Aktivität erfahren?
  - Broschüre / Postkarte in der Post
  - E-Mail-Ankündigung
  - Persönlicher Brief / Einladung
  - Direktor / Supervisor
  - Andere
- Wenn anders, bitte spezifizieren
- Telefonnummer
  Dieses Feld ist für die Zwecke der Validierung und sollten unverändert bleiben.